@@ -3,7 +3,7 @@
    xsane-batch-scan.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2007 Oliver Rauch
+   Copyright (C) 1998-2010 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -345,7 +345,7 @@ static void xsane_batch_scan_load_list(void)
   sprintf(windowname, "%s %s %s", xsane.prog_name, WINDOW_LOAD_BATCH_LIST, xsane.device_text);
   xsane_back_gtk_make_path(sizeof(filename), filename, "xsane", "batch-lists", 0, "default", ".xbl", XSANE_PATH_LOCAL_SANE);
 
-  if (!xsane_back_gtk_get_filename(windowname, filename, sizeof(filename), filename, NULL, FALSE, FALSE, FALSE, FALSE))
+  if (!xsane_back_gtk_get_filename(windowname, filename, sizeof(filename), filename, NULL, NULL, XSANE_FILE_CHOOSER_ACTION_OPEN, XSANE_GET_FILENAME_SHOW_NOTHING, XSANE_FILE_FILTER_ALL | XSANE_FILE_FILTER_BATCHLIST, XSANE_FILE_FILTER_BATCHLIST))
   {
     if (xsane_batch_scan_load_list_from_file(filename)) /* error while loading file ? */
     {
@@ -396,7 +396,7 @@ static void xsane_batch_scan_save_list(void)
   sprintf(windowname, "%s %s %s", xsane.prog_name, WINDOW_SAVE_BATCH_LIST, xsane.device_text);
   xsane_back_gtk_make_path(sizeof(filename), filename, "xsane", "batch-lists", 0, "default", ".xbl", XSANE_PATH_LOCAL_SANE);
 
-  if (!xsane_back_gtk_get_filename(windowname, filename, sizeof(filename), filename, NULL, FALSE, FALSE, FALSE, FALSE))
+  if (!xsane_back_gtk_get_filename(windowname, filename, sizeof(filename), filename, NULL, NULL, XSANE_FILE_CHOOSER_ACTION_SAVE, XSANE_GET_FILENAME_SHOW_NOTHING, XSANE_FILE_FILTER_ALL | XSANE_FILE_FILTER_BATCHLIST, XSANE_FILE_FILTER_BATCHLIST));
   {
     fd = open(filename, O_WRONLY | O_CREAT | O_TRUNC, 0600);
 
@@ -866,16 +866,15 @@ static void xsane_batch_scan_rename_callback(GtkWidget *widget, gpointer data)
       xsane_set_window_icon(rename_dialog, 0);
 
       /* set the main vbox */
-      vbox = gtk_vbox_new(FALSE, 0);
-      gtk_container_set_border_width(GTK_CONTAINER(vbox), 0);
+      vbox = gtk_vbox_new(FALSE, 10);
+      gtk_container_set_border_width(GTK_CONTAINER(vbox), 10);
       gtk_container_add(GTK_CONTAINER(rename_dialog), vbox);
       gtk_widget_show(vbox);
 
       /* set the main hbox */
       hbox = gtk_hbox_new(FALSE, 0);
-      xsane_separator_new(vbox, 2);
-      gtk_box_pack_end(GTK_BOX(vbox), hbox, FALSE, FALSE, 5);
-      gtk_container_set_border_width(GTK_CONTAINER(hbox), 5);
+      gtk_box_pack_end(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+      gtk_container_set_border_width(GTK_CONTAINER(hbox), 0);
       gtk_widget_show(hbox);
 
       gtk_window_set_position(GTK_WINDOW(rename_dialog), GTK_WIN_POS_CENTER);
@@ -893,6 +892,17 @@ static void xsane_batch_scan_rename_callback(GtkWidget *widget, gpointer data)
       gtk_box_pack_start(GTK_BOX(vbox), text, TRUE, TRUE, 4);
       gtk_widget_show(text);
 
+
+#ifdef HAVE_GTK2
+      button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
+#else
+      button = gtk_button_new_with_label(BUTTON_CANCEL);
+#endif
+      g_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc) xsane_batch_scan_rename_button_callback, (void *) -1);
+      gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
+      gtk_widget_show(button);
+
+
 #ifdef HAVE_GTK2
       button = gtk_button_new_from_stock(GTK_STOCK_OK);
 #else
@@ -905,15 +915,6 @@ static void xsane_batch_scan_rename_callback(GtkWidget *widget, gpointer data)
       gtk_widget_show(button);
 
 
-#ifdef HAVE_GTK2
-      button = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
-#else
-      button = gtk_button_new_with_label(BUTTON_CANCEL);
-#endif
-      g_signal_connect(GTK_OBJECT(button), "clicked", (GtkSignalFunc) xsane_batch_scan_rename_button_callback, (void *) -1);
-      gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
-      gtk_widget_show(button);
-
       xsane_batch_scan_rename = 0;
 
       while (xsane_batch_scan_rename == 0)
