@@ -3,7 +3,7 @@
    xsane-fixedtext.h
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2005 Oliver Rauch
+   Copyright (C) 1998-2007 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -37,6 +37,7 @@
 #define XSANE_FILETYPE_PNG		".png"
 #define XSANE_FILETYPE_PNM		".pnm"
 #define XSANE_FILETYPE_PS		".ps"
+#define XSANE_FILETYPE_PDF		".pdf"
 #define XSANE_FILETYPE_RGBA		".rgba"
 #define XSANE_FILETYPE_TEXT		".txt"
 
@@ -45,6 +46,7 @@
 #define MENU_ITEM_FILETYPE_PNG		"PNG"
 #define MENU_ITEM_FILETYPE_PNM		"PNM"
 #define MENU_ITEM_FILETYPE_PS		"PostScript"
+#define MENU_ITEM_FILETYPE_PDF		"PDF"
 #define MENU_ITEM_FILETYPE_RGBA		"RGBA"
 #define MENU_ITEM_FILETYPE_TEXT		"TEXT"
 
