@@ -3,7 +3,7 @@
    xsane-scan.h
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2002 Oliver Rauch
+   Copyright (C) 1998-2007 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,6 @@
 
 extern void xsane_scan_done(SANE_Status status);
 extern void xsane_cancel(void);
-extern void xsane_scan_dialog(void);
+extern gint xsane_scan_dialog(gpointer *data);
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
