@@ -3,7 +3,7 @@
    xsane-setup.h
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2002 Oliver Rauch
+   Copyright (C) 1998-2007 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,12 @@
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
+#ifndef XSANE_SETUP_H
+# define XSANE_SETUP_H
+
 extern void xsane_new_printer(void);   
 extern void xsane_update_int(GtkWidget *widget, int *val);
 extern void xsane_setup_dialog(GtkWidget *widget, gpointer data);
 
+#endif
 /* ---------------------------------------------------------------------------------------------------------------------- */
